@@ -23,6 +23,9 @@
 #include <ags/audio/ags_audio_buffer_util.h>
 #include <ags/audio/ags_fourier_transform_util.h>
 
+gpointer ags_fast_pitch_util_strct_copy(gpointer ptr);
+void ags_fast_pitch_util_strct_free(gpointer ptr);
+
 /**
  * SECTION:ags_fast_pitch_util
  * @short_description: fast pitch util
@@ -33,6 +36,41 @@
  * Utility functions to pitch.
  */
 
+GType
+ags_fast_pitch_util_get_type(void)
+{
+  static volatile gsize g_define_type_id__volatile = 0;
+
+  if(g_once_init_enter (&g_define_type_id__volatile)){
+    GType ags_type_fast_pitch_util = 0;
+
+    ags_type_fast_pitch_util =
+      g_boxed_type_register_static("AgsFastPitchUtil",
+				   (GBoxedCopyFunc) ags_fast_pitch_util_strct_copy,
+				   (GBoxedFreeFunc) ags_fast_pitch_util_strct_free);
+
+    g_once_init_leave(&g_define_type_id__volatile, ags_type_fast_pitch_util);
+  }
+
+  return g_define_type_id__volatile;
+}
+
+gpointer
+ags_fast_pitch_util_strct_copy(gpointer ptr)
+{
+  gpointer retval;
+
+  retval = g_memdup(ptr, sizeof(AgsFastPitchUtil));
+ 
+  return(retval);
+}
+
+void
+ags_fast_pitch_util_strct_free(gpointer ptr)
+{
+  g_free(ptr);
+}
+
 /**
  * ags_fast_pitch_util_compute_s8:
  * @buffer: the audio buffer
